@@ -547,10 +547,11 @@ def generate_ros_distro_diff(track, repository, distro, override_release_reposit
             info("Valid maintenance statuses:")
             info("- developed: active development is in progress")
             info("- maintained: no new development, but bug fixes and pull requests are addressed")
+            info("- unmaintained: looking for new maintainer, bug fixes and pull requests will not be addressed")
             info("- end-of-life: should not be used, will disappear at some point")
             while True:
                 status = safe_input('Status: ')
-                if status in ['developed', 'maintained', 'end-of-life']:
+                if status in ['developed', 'maintained', 'unmaintained', 'end-of-life']:
                     break
                 error("'{0}' is not a valid status.".format(status))
                 if not maybe_continue(msg='Try again'):
@@ -624,7 +625,6 @@ def generate_ros_distro_diff(track, repository, distro, override_release_reposit
 
 
 def get_gh_info(url):
-    from urlparse import urlparse
     o = urlparse(url)
     if 'raw.github.com' not in o.netloc and 'raw.githubusercontent.com' not in o.netloc:
         return None, None, None, None
@@ -854,7 +854,7 @@ Increasing version of package(s) in repository `{repository}` to `{version}`:
             info(fmt("@{cf}Pull Request Title: @{yf}" + sanitize(title)))
             info(fmt("@{cf}Pull Request Body : \n@{yf}" + sanitize(body)))
             msg = fmt("@!Open a @|@{cf}pull request@| @!@{kf}from@| @!'@|@!@{bf}" +
-                      "{head_repo}/{head_repo}:{new_branch}".format(**locals()) +
+                      "{head_org}/{head_repo}:{new_branch}".format(**locals()) +
                       "@|@!' @!@{kf}into@| @!'@|@!@{bf}" +
                       "{base_org}/{base_repo}:{base_branch}".format(**locals()) +
                       "@|@!'?")
